@@ -1,6 +1,5 @@
 mod quakeml;
 
-use std::path::Path;
 use structopt::StructOpt;
 
 #[derive(StructOpt)]
@@ -11,7 +10,6 @@ struct Cli {
 
 fn main() {
     let args = Cli::from_args();
-    let filename = Path::new(&args.path);
-    let data = quakeml::read_quakeml(filename);
-    quakeml::deserialize_quakeml(data);
+    let catalog = quakeml::read_quakeml(&args.path);
+    println!("{}", catalog);
 }
